==> scanbot_sdk-2.0.1.tar.gz: lib/barcode_parsers/vcard.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_parsers/barcode_scanner.dart';

part 'vcard.g.dart';

/// VCard parsed barcode document
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class VCardDocument extends BarcodeFormattedResult {
  static const String DOCUMENT_FORMAT = "VCard";

  /// Document fields */
  List<VCardDocumentField> fields;

  VCardDocument(this.fields) : super(DOCUMENT_FORMAT);

  factory VCardDocument.fromJson(Map<String, dynamic> json) =>
      _$VCardDocumentFromJson(json);

  Map<String, dynamic> toJson() => _$VCardDocumentToJson(this);
}

/// VCARD document field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class VCardDocumentField {
  /// Field type
  VCardDocumentFieldType type = VCardDocumentFieldType.Custom;

  /// Type modifiers
   List<String> typeModifiers;

  /// Values
   List<String> values;

   String rawText;


  factory VCardDocumentField.fromJson(Map<String, dynamic> json) =>
      _$VCardDocumentFieldFromJson(json);


  VCardDocumentField(this.type, this.typeModifiers, this.values, this.rawText);

  Map<String, dynamic> toJson() => _$VCardDocumentFieldToJson(this);
}

/// VCard document field type
 enum VCardDocumentFieldType {
  BeginTag, // BEGIN
  EndTag, // END
  Version, // VERSION
  Source, // SOURCE
  Kind, // KIND
  XML, // XML
  Name, // N
  FirstName, // FN
  Nickname, // NICKNAME
  Birthday, // BDAY
  Anniversary, // ANNIVERSARY
  Gender, // GENDER
  DeliveryAddress, // ADR
  Photo, // PHOTO
  TelephoneNumber, // TEL
  Email, // EMAIL
  IMPP, // IMPP
  Languages, // LANG
  TimeZone, // TZ
  GeoLocation, // GEO
  Title, // TITLE
  Role, // ROLE
  Logo, // LOGO
  Organisation, // ORG
  Member, // MEMBER
  Related, // RELATED
  Categories, // CATEGORIES
  Note, // NOTE
  ProductId, // PRODID
  Revision, // REV
  Sound, // SOUND
  UID, // UID
  ClientPIDMap, // CLIENTPIDMAP
  URL, // URL
  PublicKey, // KEY
  BusyTimeURL, // FBURL
  CalendarURIForRequests, // CALADRURI
  CalendarURI, // CALURI
  Custom
}

==> scanbot_sdk-2.9.0.tar.gz: lib/barcode_parsers/vcard.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_parsers/barcode_scanner.dart';

part 'vcard.g.dart';

/// VCard parsed barcode document
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class VCardDocument extends BarcodeFormattedResult {
  static const String DOCUMENT_FORMAT = 'VCard';

  /// Document fields */
  List<VCardDocumentField> fields;

  VCardDocument(this.fields) : super(DOCUMENT_FORMAT);

  factory VCardDocument.fromJson(Map<String, dynamic> json) =>
      _$VCardDocumentFromJson(json);

  @override
  Map<String, dynamic> toJson() => _$VCardDocumentToJson(this);
}

/// VCARD document field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class VCardDocumentField {
  /// Field type
  VCardDocumentFieldType type = VCardDocumentFieldType.Custom;

  /// Type modifiers
  List<String> typeModifiers;

  /// Values
  List<String> values;

  String rawText;

  factory VCardDocumentField.fromJson(Map<String, dynamic> json) =>
      _$VCardDocumentFieldFromJson(json);

  VCardDocumentField(this.type, this.typeModifiers, this.values, this.rawText);

  Map<String, dynamic> toJson() => _$VCardDocumentFieldToJson(this);
}

/// VCard document field type
enum VCardDocumentFieldType {
  BeginTag, // BEGIN
  EndTag, // END
  Version, // VERSION
  Source, // SOURCE
  Kind, // KIND
  XML, // XML
  Name, // N
  FirstName, // FN
  Nickname, // NICKNAME
  Birthday, // BDAY
  Anniversary, // ANNIVERSARY
  Gender, // GENDER
  DeliveryAddress, // ADR
  Photo, // PHOTO
  TelephoneNumber, // TEL
  Email, // EMAIL
  IMPP, // IMPP
  Languages, // LANG
  TimeZone, // TZ
  GeoLocation, // GEO
  Title, // TITLE
  Role, // ROLE
  Logo, // LOGO
  Organisation, // ORG
  Member, // MEMBER
  Related, // RELATED
  Categories, // CATEGORIES
  Note, // NOTE
  ProductId, // PRODID
  Revision, // REV
  Sound, // SOUND
  UID, // UID
  ClientPIDMap, // CLIENTPIDMAP
  URL, // URL
  PublicKey, // KEY
  BusyTimeURL, // FBURL
  CalendarURIForRequests, // CALADRURI
  CalendarURI, // CALURI
  Custom
}
